import { TypesUtils } from '@utils-fns/utils';

type MinMaxParamsEmail = {
    min?: number;
    max?: number;
};
type ParamsValidatorEmail = {
    minMaxUserNameEmail?: MinMaxParamsEmail;
    minMaxEmailDomain?: MinMaxParamsEmail;
    emailDomainName?: RegExp;
};
type EmailValidator = {
    email?: string;
    paramsEmailValidator?: ParamsValidatorEmail;
};

type CustomPatternPhone = {
    coutryCode: RegExp;
    areaStateCode: RegExp;
    phoneNumber: RegExp;
};
type ParamsPhoneValidator = {
    onlyMobilePhoneBR?: boolean;
    canReceiveInternationalNumbers?: boolean;
    customPatternPhone?: CustomPatternPhone;
    publicUtilityNumberBR?: boolean;
    numberWithoutCodeAreas?: boolean;
};
type PhoneValidator = {
    phone?: string;
    paramsPhoneValidator?: ParamsPhoneValidator;
};

type TypeCard = 'credit' | 'debit' | 'credit-debit';
type BrandCard = TypesUtils['BrandCardType'];
type ParamsPaymentCardValidator = {
    validationTypeCard?: TypeCard;
    specificBrandCard?: BrandCard;
    customPatternPaymentCard?: RegExp;
};
type PaymentCardValidator = {
    cardNumber?: string;
    paramsPaymentCardValidator?: ParamsPaymentCardValidator;
};

type TypesValidators = {
    EmailValidator: EmailValidator;
    MinMaxParamsEmail: MinMaxParamsEmail;
    ParamsValidatorEmail: ParamsValidatorEmail;
    PhoneValidator: PhoneValidator;
    ParamsPhoneValidator: ParamsPhoneValidator;
    CustomPatternPhone: CustomPatternPhone;
    BrandCard: BrandCard;
    ParamsPaymentCardValidator: ParamsPaymentCardValidator;
    PaymentCardValidator: PaymentCardValidator;
    TypeCard: TypeCard;
};
declare const validators: {
    cpf: (cpf?: string | undefined) => boolean;
    cnpj: (cnpj?: string | undefined) => boolean;
    email: ({ email, paramsEmailValidator, }: EmailValidator) => boolean;
    nis: (nis?: string | undefined) => boolean;
    phone: ({ phone, paramsPhoneValidator, }: PhoneValidator) => boolean;
    paymentCardValidator: ({ cardNumber, paramsPaymentCardValidator, }: PaymentCardValidator) => boolean;
};

export { TypesValidators, validators };
